/**
  ******************************************************************************
  * @file    hw_config.h
  * @author  MCD Application Team
  * @version V2.0.0
  * @date    11-July-2011
  * @brief   Target config file module.
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */
  
/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __HARDWARE_CONFIG_H
#define __HARDWARE_CONFIG_H

/** @addtogroup Embedded_GUI_Example
  * @{
  */

/** @addtogroup HWConfig
  * @{
  */

#ifdef __cplusplus
 extern "C" {
#endif 
   

/* Includes ------------------------------------------------------------------*/
#include "stm32f4xx.h"
#include "stm32f4_discovery.h"

#include <stdio.h>
#include "LcdHal.h"
#include "TscHal.h"


/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/* IOE I2C device address */
#define TSC_I2C_DEVICE_REGISTER     0x82
#define JOY_I2C_DEVICE_REGISTER     0x88

/** 
  * @brief   Touchscreen Controller DEFINES  
  */ 
/* Touchscreen Controller DEFINES for DevKit407 */
#ifdef DevKit407
 #define TSC_I2C_PORT              I2C1
 #define TSC_I2C_CLK               RCC_APB1Periph_I2C1
 #define TSC_I2C_SDA_GPIO_PIN      GPIO_Pin_9
 #define TSC_I2C_SDA_GPIO_PORT     GPIOB
 #define TSC_I2C_SDA_GPIO_CLK      RCC_AHB1Periph_GPIOB
 #define TSC_I2C_SDA_SOURCE        GPIO_PinSource9
 #define TSC_I2C_SDA_AF            GPIO_AF_I2C1
 #define TSC_I2C_SCL_GPIO_PIN      GPIO_Pin_8
 #define TSC_I2C_SCL_GPIO_PORT     GPIOB
 #define TSC_I2C_SCL_GPIO_CLK      RCC_AHB1Periph_GPIOB
 #define TSC_I2C_SCL_SOURCE        GPIO_PinSource8
 #define TSC_I2C_SCL_AF            GPIO_AF_I2C1
 #define TSC_GPIO_PIN_SOURCE       GPIO_PinSource13
 #define TSC_IT_EXTI_PIN_SOURCE    EXTI_PinSource13
 #define TSC_GPIO_PORT_SOURCE      EXTI_PortSourceGPIOC
 #define TSC_EXTI_IRQ_CHANNEL      EXTI15_10_IRQn
 #define TSC_EXTI_LINE             EXTI_Line13
 #define TSC_IT_GPIO_CLK           RCC_AHB1Periph_GPIOC
 #define TSC_IT_GPIO_PORT          GPIOC
 #define TSC_IT_GPIO_PIN           GPIO_Pin_13
#endif

/** 
  * @brief   KEY Button Controller DEFINES  
  */ 
/* User Button GPIO Port and Pin*/
#ifdef STM32F4Discovery
  #define USER_BUTTON_BUS_PERIPH   RCC_AHB1Periph_GPIOA
  #define USER_BUTTON_PORT         GPIOA
  #define USER_BUTTON_PIN          GPIO_Pin_0
  #define USER_BUTTON_PIN_ACTIVE   Bit_SET
#endif

/** 
  * @brief   LCD Controller DEFINES  
  */ 
#ifdef DevKit407
  /* LCD Controller DEFINES for DevKit407 */
  #define LCD_RCC_BUS_PERIPH       RCC_AHB3Periph_FSMC
  #define LCD_CONNECTION_MODE      GL_FSMC
#endif


/* Exported macros -----------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */ 
   void HWConfig_SetHardwareParams(void);
   
#ifdef __cplusplus
}
#endif

#endif /* __HARDWARE_CONFIG_H */

   
/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
