/**
  ******************************************************************************
  * @file    graphicObjectTypes.h
  * @author  MCD Application Team
  * @version V2.0.0
  * @date    11-July-2011
  * @brief   This file contains all the specific Graphics Object types
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */

/* Define to prevent recursive inclusion ---------------------------------------*/
#ifndef __GRAPHIC_OBJECT_TYPES_H
#define __GRAPHIC_OBJECT_TYPES_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "stm32HAL.h"

/** @addtogroup Embedded_GUI_Library
  * @{
  */

/** @defgroup graphicObjectTypes
  * @{
  */

  /* Exported constants --------------------------------------------------------*/
/** @defgroup graphicObjectTypes_Exported_Defines
  * @{
  */
#define MAX_CTRL_X_PAGE                      30
#define MAX_NAME_LENGTH                      22
#define MAX_LABEL_LENGTH                     46
#define MAX_BUTTON_LABEL_LENGTH              16
#define MAX_CHECKBOX_LABEL_LENGTH            25
#define MAX_RADIO_OPTION_LABEL_LENGTH        16
#define MAX_RADIO_OPTIONS                     3
#define MAX_COMBO_OPTIONS                    10
#define MAX_COMBO_LABEL_LENGTH               12
#define MAX_SWITCH_LABEL_LENGTH              16
#define MAX_SLIDE_LABEL_LENGTH               16
#define MAX_HIST_LABEL_LENGTH                 7
#define MAX_GRAPH_LABEL_LENGTH                7
#define MAX_HIST_POINTS                      50
#define MAX_GRAPH_POINTS                    100
#define HIST_MARGIN_LENGTH                   20
#define GRAPH_MARGIN_LENGTH                  18

/**
  * @}
  */

/* Exported types ------------------------------------------------------------*/
/** @defgroup graphicObjectTypes_Exported_Types
  * @{
  */

/**
  * @brief  GL_FunctionalState enumeration definition
  */
typedef enum
{
   GL_DISABLE = 0,
   GL_ENABLE = !GL_DISABLE
} GL_FunctionalState;

/**
  * @brief  GL_ButtonStatus enumeration definition
  */
typedef enum {
    UNSELECTED = 0,
    SELECTED = 1,
    GL_UNKNOWN = 2
}GL_ButtonStatus;

/* Forward declaration for circular typedefs */
typedef struct GL_PageControlsObj GL_PageControls_TypeDef;
typedef struct GL_PageObj GL_Page_TypeDef;
typedef struct ListboxItem ListboxItem_TypeDef;
typedef struct GL_ButtonObj GL_Button_TypeDef;
typedef struct GL_ButtonColorObj GL_ButtonColor_TypeDef;
typedef struct GL_CheckboxObj GL_Checkbox_TypeDef;
typedef struct GL_ComboBoxGrp GL_ComboBoxGrp_TypeDef;
typedef struct GL_ComboOptionObj GL_ComboOption_TypeDef;
typedef struct GL_DrawboxObj GL_Drawbox_TypeDef;
typedef struct GL_GraphChartObj GL_GraphChart_TypeDef;
typedef struct GL_HistogramObj GL_Histogram_TypeDef;
typedef struct GL_IconObj GL_Icon_TypeDef;
typedef struct GL_KeyboardObj GL_Keyboard_TypeDef;
typedef struct GL_LabelObj GL_Label_TypeDef;
typedef struct GL_ListboxObj GL_Listbox_TypeDef;
typedef struct GL_RadioButtonGrp GL_RadioButtonGrp_TypeDef;
typedef struct GL_RadioButtonOptionObj GL_RadioOption_TypeDef;
typedef struct GL_SlidebarObj GL_Slidebar_TypeDef;
typedef struct GL_SwitchObj GL_Switch_TypeDef;
typedef struct GL_TextboxObj GL_Textbox_TypeDef;

/**
  * @brief  GL_bool enumeration definition
  */
typedef enum
{
   GL_FALSE = 0,
   GL_TRUE = !GL_FALSE
} GL_bool;

/**
  * @brief  GL_ErrStatus enumeration definition
  */
typedef enum {
    GL_ERROR = 0,
    GL_OK = !GL_ERROR
}GL_ErrStatus;

/**
  * @brief  GL_Direction enumeration definition
  */
typedef enum {
    GL_HORIZONTAL = 0,
    GL_LEFT_VERTICAL,
    GL_RIGHT_VERTICAL
}GL_Direction;

/**
  * @brief  GL_ObjType enumeration definition
  */
typedef enum{
  GL_BUTTON = 1,
  GL_RADIO_BUTTON = 2,
  GL_CHECKBOX = 3,
  GL_LABEL = 4,
  GL_SWITCH = 5,
  GL_ICON = 6,
  GL_COMBOBOX = 7,
  GL_SLIDEBAR = 8,
  GL_HISTOGRAM = 9,
  GL_GRAPH_CHART = 10,
  GL_LISTBOX = 11,
  GL_TEXTBOX = 12,
  GL_BUTTON_COLOR,
  GL_DRAWBOX,
} GL_ObjType;

/**
  * @brief  GL_Coordinates structure definition
  */
typedef struct
{
  uint16_t MaxX;
  uint16_t MinX;
  uint16_t MaxY;
  uint16_t MinY;
} GL_Coordinates_TypeDef;

/**
  * @brief  GL_ObjDimensions structure definition
  */
typedef struct
{
  uint16_t Height;
  uint16_t Length;
} GL_ObjDimensions_TypeDef;

/**
  * @brief  GL_PageControlsObj structure definition
  */
struct GL_PageControlsObj
{
  uint16_t               ID;
  void*                  objPTR;
  GL_Coordinates_TypeDef objCoordinates;
  GL_ObjType             objType;
  GL_ErrStatus           (*SetObjVisible)(GL_PageControls_TypeDef* pObj, GL_Coordinates_TypeDef objCoordinates);
};

/**
  * @brief  GL_PageObj struct definition
  */
struct GL_PageObj
{
  uint8_t                  objName[MAX_NAME_LENGTH];
  GL_bool                  Page_Active;
  GL_bool                  Page_Visible;
  uint16_t                 ControlCount;
  GL_ErrStatus             (*ShowPage)(GL_Page_TypeDef* pThis, GL_bool bVal);
  GL_PageControls_TypeDef* PageControls[MAX_CTRL_X_PAGE];
  GL_ErrStatus             (*SetPage)(GL_Page_TypeDef* pThis, GL_bool bVal);
  GL_bool                  (*GetObjStatus)(GL_Page_TypeDef* pThis, uint16_t ID);
  GL_Coordinates_TypeDef    (*GetObjCoordinates)(GL_Page_TypeDef* pThis, uint16_t ID);
};

/**
  * @brief  ListBoxItem structure definition
  */
struct ListboxItem
{
  ListboxItem_TypeDef* PrevItem;
  ListboxItem_TypeDef* NextItem;
  GL_bool              ItemSelected;
  uint8_t*             Text;
};

/**
  * @brief  GL_ButtonObj structure definition
  */
struct GL_ButtonObj
{
  uint16_t          ID;
  uint8_t*          Label;
  GL_bool           Control_Visible;
  GL_bool           ObjectTouched;
  void              (*EventHandler)(void);
};

/**
  * @brief  GL_ButtonColorObj structure definition
  */
struct GL_ButtonColorObj
{
  uint16_t          ID;
  uint16_t          Color;
  GL_bool           Control_Visible;
  GL_bool           ObjectTouched;
  void              (*EventHandler)(void);
};

/**
  * @brief  GL_CheckboxObj structure definition
  */
struct GL_CheckboxObj
{
  uint16_t          ID;
  uint8_t*          Label;
  GL_bool           Checked;
  GL_bool           Control_Visible;
  void              (*EventHandler)(void);
};

/**
  * @brief  GL_ComboBoxGrp structure definition
  */
struct GL_ComboBoxGrp
{
  uint16_t                  ID;
  uint16_t                  ComboOptionCount;
#ifndef USE_2D_OBJECTS
  uint8_t*                  ImageClickedPTR;
  uint8_t*                  ImageUnClickedPTR;
#endif
  GL_bool                   Control_Visible;
  GL_bool                   Secondary;
  GL_PageControls_TypeDef*  PrimaryComboOpt;
  GL_ComboOption_TypeDef*   ComboOptions[MAX_COMBO_OPTIONS];
  GL_ErrStatus              (*AddComboOption)( GL_ComboBoxGrp_TypeDef* pThis, const char* Label, void (*pEventHandler)(void) );
};

/**
  * @brief  GL_ComboOptionObj structure definition
  */
struct GL_ComboOptionObj
{
  uint16_t                 BackColor;
  uint16_t                 TextColor;
  GL_ComboBoxGrp_TypeDef*  ComboBoxGrp;
  uint8_t*                 Label;
  GL_bool                  Active;
  void                     (*EventHandler)(void);
};

/**
  * @brief  GL_DrawboxObj structure definition
  */
struct GL_DrawboxObj
{
  uint16_t                 ID;
  uint16_t                 Width;
  uint16_t                 Height;
  void                     (*EventHandler)(uint16_t x, uint16_t y);
};

/**
  * @brief  GL_GraphChartObj structure definition
  */
struct GL_GraphChartObj
{
  uint16_t          ID;
  uint8_t*          Label_X;
  uint8_t*          Label_Y;
  int16_t           Points[MAX_GRAPH_POINTS];
  uint8_t           NrOfPoints;
  GL_bool           Background;
  GL_bool           Control_Visible;
};

/**
  * @brief  GL_HistogramObj structure definition
  */
struct GL_HistogramObj
{
  uint16_t          ID;
  uint8_t*          Label_X;
  uint8_t*          Label_Y;
  uint8_t           NrOfPoints;
  int16_t           Points[MAX_HIST_POINTS];
  GL_bool           Control_Visible;
};

/**
  * @brief  GL_IconObj structure definition
  */
struct GL_IconObj
{
  uint16_t          ID;
  const uint8_t*    ImagePTR;
  uint16_t          ImageWidth;
  uint8_t           ImageHeight;
  GL_bool           Control_Visible;
  GL_bool           ObjectTouched;
  void              (*EventHandler)(void);
};

/**
  * @brief  GL_LabelObj structure definition
  */
struct GL_LabelObj
{
  uint16_t          ID;
  uint8_t*          Label;
  uint8_t           FontSize;
  uint16_t          Colour;
  GL_bool           Control_Visible;
  GL_Direction      Direction;
};

/**
  * @brief  GL_ListboxObj structure definition
  */
struct GL_ListboxObj
{
  uint16_t             ID;
  uint16_t             Width;
  uint16_t             Height;
  uint16_t             NrOfItems;
  uint16_t             NrOfFirstItem;
  int16_t              NrOfLastSelItem;
  GL_bool              MultiSelection;
  ListboxItem_TypeDef* Item;
  void                 (*EventHandler)(uint16_t index);
};

/**
  * @brief  GL_RadioButtonGrp structure definition
  */
struct GL_RadioButtonGrp
{
  uint16_t                 ID;
  uint16_t                 RadioOptionCount;
  GL_PageControls_TypeDef* RadioOptions[MAX_RADIO_OPTIONS];
  GL_PageControls_TypeDef* (*AddRadioOption)( GL_RadioButtonGrp_TypeDef* pObj, const char* Label, void (*pEventHandler)(void) );
};

/**
  * @brief  GL_RadioButtonOptionObj structure definition
  */
struct GL_RadioButtonOptionObj
{
  GL_RadioButtonGrp_TypeDef* RadioButtonGrp;
  uint8_t*                   Label;
  GL_bool                    Control_Visible;
  GL_bool                    Checked;
  void                       (*EventHandler)(void);
};

/**
  * @brief  GL_SlidebarObj structure definition
  */
struct GL_SlidebarObj
{
  uint16_t          ID;
  uint8_t*          Label;
  uint8_t           Width;
  uint8_t           Length;
  uint8_t           CurrentValue;
  uint8_t           PreviousValue;
  uint8_t           MinValue;
  uint8_t           MaxValue;
  uint16_t*          BehindCursor;//?
  GL_bool           Control_Visible;
  GL_Direction      Direction;
  void              (*EventHandler)(void);
};

/**
  * @brief  GL_SwitchObj structure definition
  */
struct GL_SwitchObj
{
  uint16_t          ID;
  uint8_t*          Label_1;
  uint8_t*          Label_2;
  GL_bool           Control_Visible;
  GL_bool           ObjectTouched;
  void              (*EventHandler)(void);
};

/**
  * @brief  Struktura GL_TextboxObj definiuje obiekt typu Textbox
  */
struct GL_TextboxObj
{
  uint16_t             ID;             // Unikalny numer ID obiektu
  uint16_t             Width;          // Szerokosc komponentu
  uint16_t             Height;         // Wysokosc komponentu
  uint8_t*             Text;           // Wskaznik na ciag znakow zakonczony NULLem
};


/**
  * @}
  */

/**
  * @}
  */

/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */

#ifdef __cplusplus
}
#endif

#endif /*__GRAPHIC_OBJECT_TYPES_H */

/**
  * @}
  */

/**
  * @}
  */

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
